@@ -32,6 +32,7 @@
 (declare-function ediff-regions-internal "ediff")
 (declare-function ediff-make-cloned-buffer "ediff-utils")
 (declare-function org-escape-code-in-string "org-src")
+(declare-function gptel--vterm-delete "gptel-integrations")
 
 
 ;; * Helper functions and vars
@@ -73,13 +74,11 @@ global value."
     (_ (kill-local-variable sym)
        (set sym value))))
 
-(defvar gptel--preset nil
-  "Name of last applied gptel preset.
-
-For internal use only.")
-
 (defun gptel--preset-mismatch-p (name)
-  "Check if gptel preset with NAME is in effect."
+  "Check if gptel preset with NAME is in effect.
+
+This is intended to be fast but imperfect.  See
+`gptel--preset-mismatch-value' for more granular checking."
   (let ((elm (or (gptel-get-preset name)
                  (gptel-get-preset (intern-soft name))))
         key val)
@@ -540,7 +539,6 @@ which see."
                                   ('t "buffer-locally")
                                   (_ "globally")))
                         gptel--known-presets nil t)))))
-  (gptel--set-with-scope 'gptel--preset name gptel--set-buffer-locally)
   (gptel--apply-preset
    name (lambda (sym val)
           (gptel--set-with-scope sym val gptel--set-buffer-locally)))
@@ -1770,7 +1768,11 @@ This sets the variable `gptel-include-tool-results', which see."
       ;; text is killed below.
       (when in-place
         (if (or buffer-read-only (get-char-property (point) 'read-only))
-            (message "Not replacing prompt: region is read-only")
+            (cond
+             ((derived-mode-p 'vterm-mode)
+              (require 'gptel-integrations)
+              (gptel--vterm-delete))
+             (t (message "Not replacing prompt: region is read-only")))
           (let ((beg (if (use-region-p)
                          (region-beginning)
                        (max (previous-single-property-change
@@ -1868,7 +1870,7 @@ This uses the prompts in the variable
           (gptel--set-with-scope
            'gptel--system-message prompt gptel--set-buffer-locally)
           (gptel--edit-directive 'gptel--system-message
-            :callback (lambda () (call-interactively #'gptel-menu)))))
+            :callback (lambda (_) (call-interactively #'gptel-menu)))))
     (message "No prompts available.")))
 
 (transient-define-suffix gptel--suffix-system-message (&optional cancel)
